
Authors
=======

* Paulo Radatz - https://www.linkedin.com/in/pauloradatz/ and paulo.radatz@gmail.com
* Ênio Viana - https://www.linkedin.com/in/enioviana/ and eniocc@gmail.com
* Rodolfo Pilar Londero - https://www.linkedin.com/in/rodolfolondero/ and rodolfopl@gmail.com
